<?php
/**
 * MyBB 1.4 News Bar Plugin
 * Copyright  2008 Phenomenon, All Rights Reserved
 */

// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

$plugins->add_hook("admin_load", "newsbar_admin");
$plugins->add_hook("admin_config_menu", "newsbar_admin_config_menu");
$plugins->add_hook("admin_config_action_handler", "newsbar_admin_config_action_handler");
$plugins->add_hook("admin_config_permissions", "newsbar_admin_config_permissions");
$plugins->add_hook("global_start", "newsbar");

function newsbar_info()
{
	global $lang;
	
	$lang->load("config_newsbar", false, true);
	
	return array(
		"name" => $lang->newsbar,
		"description" => $lang->newsbar_desc,
		"website" => "http://www.force-opponents.de",
		"author" => "Phenomenon",
		"authorsite" => "http://www.force-opponents.de",
		"version" => "1.1.4",
		"guid" => "9d08571c9f7133c79bc289a3c42100b7",
		"compatibility" => "14*"
	);
}

function newsbar_install()
{
	global $db, $mybb;
	
	// Remove old installation to avoid duplicates
	newsbar_uninstall();
	
	// Create newsbar table (default UTF8)
	$db->query("
		CREATE TABLE `".TABLE_PREFIX."newsbar` (
			`bid` int(10) unsigned NOT NULL auto_increment,
			`forumids` text NOT NULL,
			`location` text NOT NULL,
			`excludepages` text NOT NULL,
			`dateformat` text NOT NULL,
			`timeformat` text NOT NULL,
			PRIMARY KEY (bid)
		) DEFAULT CHARSET = utf8
	");
	
	// Insert default values
	$insertarray = array(
		"forumids" => 0,
		"location" => "index",
		"excludepages" => "portal.php,search.php,misc.php",
		"dateformat" => $mybb->settings['dateformat'],
		"timeformat" => $mybb->settings['timeformat']
	);
	
	$db->insert_query("newsbar", $insertarray);
	
	// Add a default stylesheet
	$insertarray = array(
		"name" => "newsbar.css",
		"tid" => 1,
		"attachedto" => "index.php",
		"stylesheet" => ".newsbar {\n\tbackground: #FFF6BF;\n\tborder-top: 2px solid #FFD324;\n\tborder-bottom: 2px solid #FFD324;\n\ttext-align: center;\n\tmargin: 10px auto;\n\tpadding: 5px 20px;\n}",
		"lastmodified" => TIME_NOW
	);
	
	$sid = $db->insert_query("themestylesheets", $insertarray);
	$db->update_query("themestylesheets", array("cachefile" => "css.php?stylesheet=".$sid), "sid = '".$sid."'", 1);
	$tids = $db->simple_select("themes", "tid");
	
	while($row = $db->fetch_array($tids))
	{
		update_theme_stylesheet_list($row['tid']);
	}
	
	// Add a default template
	$insertarray = array(
		"title" => "newsbar",
		"template" => "<div class=\"newsbar\"><strong>{\$lang->latest_news}</strong> <a href=\"{\$announcement[\'threadlink\']}\">{\$announcement[\'subject\']}</a> ({\$announcement[\'date\']})</div>",
		"sid" => -1,
		"dateline" => TIME_NOW
	);
	
	$db->insert_query("templates", $insertarray);
}

function newsbar_is_installed()
{
	global $db;
	
	if($db->table_exists("newsbar"))
	{
		return true;
	}
	
	return false;
}

function newsbar_activate()
{
	require_once MYBB_ROOT."/inc/adminfunctions_templates.php";
	
	find_replace_templatesets("header", "#<navigation>\n\t\t\t<br />#i", "<navigation>\n\t\t\t<br />\n\t\t\t{\$newsbar}");
	
	change_admin_permission("config", "newsbar");
}

function newsbar_deactivate()
{
	require_once MYBB_ROOT."/inc/adminfunctions_templates.php";
	
	find_replace_templatesets("header", "#".preg_quote("\n\t\t\t{\$newsbar}")."#i", "", 0);
	
	change_admin_permission("config", "newsbar", -1);
}

function newsbar_uninstall()
{
	global $db;
	
	// Drop newsbar table
	$db->drop_table("newsbar");
	
	// Remove the custom stylesheet
	$db->delete_query("themestylesheets", "name = 'newsbar.css'");
	
	require_once MYBB_ADMIN_DIR."inc/functions_themes.php";
	
	$query = $db->simple_select("themes", "tid");
	
	while($row = $db->fetch_array($query))
	{
		update_theme_stylesheet_list($row['tid']);
	}
	
	// Remove the custom template
	$db->delete_query("templates", "title = 'newsbar'");
}

function newsbar_admin_config_menu(&$sub_menu)
{
	global $lang;
	
	$lang->load("config_newsbar", false, true);
	
	$sub_menu[] = array(
		"id" => "newsbar",
		"title" => $lang->newsbar,
		"link" => "index.php?module=config/newsbar"
	);
}

function newsbar_admin_config_action_handler(&$actions)
{
	$actions['newsbar'] = array("active" => "newsbar", "file" => "newsbar");
}

function newsbar_admin_config_permissions($admin_permissions)
{
	global $lang;
	
	$admin_permissions['newsbar'] = $lang->can_manage_newsbar;
}

function newsbar_admin()
{
	global $db, $lang, $mybb, $page, $run_module, $action_file;
	
	if($run_module == "config" && $action_file == "newsbar")
	{
		$page->add_breadcrumb_item($lang->newsbar, "index.php?module=config/newsbar");
		
		// Fix: Load settings language file
		$lang->load("config_settings", false, true);
		
		if($mybb->input['action'] == "change")
		{
			if($mybb->request_method == "post")
			{
				if(trim($mybb->input['forumids'] == ""))
				{
					$errors[] = $lang->error_no_forum_ids;
				}
				
				if(!$errors)
				{
					// Update stylesheet file assignment
					$attachedto = "";
					
					if($mybb->input['location'] == "index")
					{
						$attachedto = "index.php";
					}
					
					$db->update_query("themestylesheets", array("attachedto" => $attachedto), "name = 'newsbar.css'");
					$query = $db->simple_select("themes", "tid");
					
					include MYBB_ADMIN_DIR."inc/functions_themes.php";
					
					while($row = $db->fetch_array($query))
					{
						update_theme_stylesheet_list($row['tid']);
					}
					
					// Update settings
					$updatearray = array(
						"forumids" => $mybb->input['forumids'],
						"location" => $mybb->input['location'],
						"excludepages" => $mybb->input['excludepages'],
						"dateformat" => $mybb->input['dateformat'],
						"timeformat" => $mybb->input['timeformat']
					);
					
					$db->update_query("newsbar", $updatearray, "bid = '".$mybb->input['bid']."'");
					
					flash_message($lang->success_settings_updated, "success");
				}
			}
		}
		
		$page->output_header($lang->newsbar);
		
		if($errors)
		{
			$page->output_inline_error($errors);
		}
		
		$query = $db->simple_select("newsbar", "*");
		$settings = $db->fetch_array($query);
		
		foreach($settings as $key => $value)
		{
			if(!$mybb->input[$key])
			{
				$mybb->input[$key] = $value;
			}
		}
		
		$form = new Form("index.php?module=config/newsbar&amp;action=change", "post", "change");
		
		echo $form->generate_hidden_field("bid", $settings['bid']);
		
		$form_container = new FormContainer($lang->newsbar);
		$form_container->output_row($lang->announcement_forum_ids, $lang->announcement_forum_ids_desc, $form->generate_text_box("forumids", $mybb->input['forumids'], array("id" => "newsbar_forumids")));
		$form_container->output_row($lang->location, $lang->location_desc, $form->generate_select_box("location", array("index" => $lang->on_forum_index, "global" => $lang->globally), $mybb->input['location'], array("id" => "newsbar_location")));
		$form_container->output_row($lang->exclude_pages, $lang->exclude_pages_desc, $form->generate_text_box("excludepages", $mybb->input['excludepages'], array("id" => "newsbar_excludepages")), "", "", array("id" => "row_newsbar_excludepages"));
		$form_container->output_row($lang->date_format, $lang->date_format_desc, $form->generate_text_box("dateformat", $mybb->input['dateformat'], array("id" => "newsbar_dateformat")));
		$form_container->output_row($lang->time_format, $lang->time_format_desc, $form->generate_text_box("timeformat", $mybb->input['timeformat'], array("id" => "newsbar_timeformat")));
		$form_container->end();
		
		$buttons[] = $form->generate_submit_button($lang->save_settings);
		
		$form->output_submit_wrapper($buttons);
		$form->end();
		
		// Output Peeker javascript
		echo "<script type=\"text/javascript\" src=\"./jscripts/peeker.js\"></script>
	<script type=\"text/javascript\">
		Event.observe(window, \"load\", function() {
			loadPeekers();			
		});
		function loadPeekers()
		{
			new Peeker($(\"newsbar_location\"), $(\"row_newsbar_excludepages\"), /global/, false);
		}
	</script>";
		
		$page->output_footer();
	}
}

function newsbar()
{
	global $db, $mybb, $templates, $lang, $current_page, $newsbar;
	
	$query = $db->simple_select("newsbar", "*");
	$settings = $db->fetch_array($query);
	
	// Use the portal settings?
	if($settings['forumids'] == 0)
	{
		$settings['forumids'] = $mybb->settings['portal_announcementsfid'];
	}
	
	// Do not display on ...
	if($settings['forumids'] == "" || ($settings['location'] == "index" && $current_page != "index.php") || newsbar_exclude_page())
	{
		return;
	}
	
	$lang->load("newsbar", false, true);
	
	$fids = explode(",", $settings['forumids']);
	
	if(is_array($fids))
	{
		foreach($fids as $fid)
		{
			$fidarray[] = intval($fid);
		}
		
		$fids = implode(",", $fidarray);
	}
	
	$query = $db->query("
		SELECT p.tid, t.subject, t.dateline
		FROM ".TABLE_PREFIX."posts p
		LEFT JOIN ".TABLE_PREFIX."threads t ON (t.tid = p.tid)
		WHERE t.fid IN (".$fids.") AND t.visible = '1' AND t.closed NOT LIKE 'moved|%' AND t.firstpost = p.pid
		ORDER BY t.dateline DESC 
		LIMIT 1
	");
	
	$announcement = $db->fetch_array($query);
	
	$announcement['subject'] = htmlspecialchars_uni($announcement['subject']);
	$announcement['threadlink'] = get_thread_link($announcement['tid']);
	$announcement['date'] = my_date($settings['dateformat'], $announcement['dateline']);
	$announcement['time'] = my_date($settings['timeformat'], $announcement['dateline']);
	
	eval("\$newsbar = \"".$templates->get("newsbar")."\";");
}

function newsbar_exclude_page()
{
	global $db, $current_page;
	
	$query = $db->simple_select("newsbar", "excludepages");
	$excludepages = $db->fetch_field($query, "excludepages");
	$pagenames = explode(",", $excludepages);
	
	foreach($pagenames as $pagename)
	{
		if($pagename == $current_page)
		{
			return true;
		}
	}
	
	return false;
}
?>